@@ -1,4 +1,5 @@
 from .order import Order
+from .settlements import Settlements
 from .constant import API_TYPE
 
 
@@ -16,4 +17,12 @@ class Payment(object):
                             mid=mid, 
                             timeout=timeout,
                             verify=verify)
+        
+        self.settlements = Settlements(base_url,
+                            apiType=apiType, 
+                            token=token, 
+                            provider=provider, 
+                            mid=mid, 
+                            timeout=timeout,
+                            verify=verify)
         
\ No newline at end of file
